summaryrefslogtreecommitdiffstats
path: root/ksystemlog/src/readerFactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksystemlog/src/readerFactory.h')
-rw-r--r--ksystemlog/src/readerFactory.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ksystemlog/src/readerFactory.h b/ksystemlog/src/readerFactory.h
index 6760d8a..4f6ce0a 100644
--- a/ksystemlog/src/readerFactory.h
+++ b/ksystemlog/src/readerFactory.h
@@ -102,9 +102,9 @@ class ReaderFactory {
static LogFiles* getApacheAccessLogFiles();
/**
* Get Postfix log files from configuration
*/
- static LogFiles* getPostfixLogFiles();
+ static LogFiles* getMailLogFiles();
/**
* Get Bool log file from configuration
@@ -102,9 +102,9 @@ class ReaderFactory {
static LogFiles* getApacheAccessLogFiles();
/**
- * Get Postfix log files from configuration
+ * Get Mail log files from configuration
*/